Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/virtualMemoryManagement/hipMemGetAllocationPropertiesFromHandle.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

149 lines
4.8 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
/**
* @addtogroup hipMemGetAllocationPropertiesFromHandle hipMemGetAllocationPropertiesFromHandle
* @{
* @ingroup VirtualMemoryManagementTest
* `hipError_t hipMemGetAllocationPropertiesFromHandle(hipMemAllocationProp* prop,
* hipMemGenericAllocationHandle_t handle)` -
* Retrieve the property structure of the given handle.
*/
#include <hip_test_common.hh>
#include "hip_vmm_common.hh"
#define DATA_SIZE (1 << 13)
/**
* Test Description
* ------------------------
* - Functional test to verify the values of hipMemAllocationProp properties.
* ------------------------
* - unit/virtualMemoryManagement/hipMemGetAllocationPropertiesFromHandle.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 6.1
*/
HIP_TEST_CASE(Unit_hipMemGetAllocationPropertiesFromHandle_functional) {
hipDevice_t device;
CTX_CREATE();
HIP_CHECK(hipDeviceGet(&device, 0));
checkVMMSupported(device);
hipMemGenericAllocationHandle_t handle;
hipMemAllocationProp prop = {};
prop.type = hipMemAllocationTypePinned;
prop.location.type = hipMemLocationTypeDevice;
prop.location.id = device;
// create a temp prop structure.
hipMemAllocationProp prop_temp = {};
size_t granularity = 0;
int N = DATA_SIZE;
size_t buffer_size = N * sizeof(int);
HIP_CHECK(
hipMemGetAllocationGranularity(&granularity, &prop, hipMemAllocationGranularityMinimum));
REQUIRE(granularity > 0);
size_t mem_size = ((granularity + buffer_size - 1) / granularity) * granularity;
// Allocate physical memory
HIP_CHECK(hipMemCreate(&handle, mem_size, &prop, 0));
// verify properties has been retrived from handle
HIP_CHECK(hipMemGetAllocationPropertiesFromHandle(&prop_temp, handle));
REQUIRE(prop_temp.type == prop.type);
REQUIRE(prop_temp.location.type == prop.location.type);
REQUIRE(prop_temp.location.id == prop.location.id);
HIP_CHECK(hipMemRelease(handle));
CTX_DESTROY();
}
/**
* Test Description
* ------------------------
* - Negative Tests.
* ------------------------
* - unit/virtualMemoryManagement/hipMemGetAllocationPropertiesFromHandle.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 6.1
*/
HIP_TEST_CASE(Unit_hipMemGetAllocationPropertiesFromHandle_Negative) {
CTX_CREATE();
hipDevice_t device;
HIP_CHECK(hipDeviceGet(&device, 0));
checkVMMSupported(device);
hipMemGenericAllocationHandle_t handle;
hipMemAllocationProp prop = {};
prop.type = hipMemAllocationTypePinned;
prop.location.type = hipMemLocationTypeDevice;
prop.location.id = device;
// create a temp prop structure.
hipMemAllocationProp prop_temp = {};
size_t granularity = 0;
int N = DATA_SIZE;
size_t buffer_size = N * sizeof(int);
HIP_CHECK(
hipMemGetAllocationGranularity(&granularity, &prop, hipMemAllocationGranularityMinimum));
REQUIRE(granularity > 0);
size_t mem_size = ((granularity + buffer_size - 1) / granularity) * granularity;
// Allocate physical memory
HIP_CHECK(hipMemCreate(&handle, mem_size, &prop, 0));
SECTION("Nullptr as prop") {
REQUIRE(hipMemGetAllocationPropertiesFromHandle(nullptr, handle) == hipErrorInvalidValue);
}
SECTION("null handle") {
prop.location.type = hipMemLocationTypeInvalid;
REQUIRE(hipMemGetAllocationPropertiesFromHandle(
&prop_temp, (hipMemGenericAllocationHandle_t) nullptr) == hipErrorInvalidValue);
}
HIP_CHECK(hipMemRelease(handle));
CTX_DESTROY();
}
HIP_TEST_CASE(Unit_hipMemGetAllocationPropertiesFromHandle_Capture) {
CTX_CREATE();
hipDevice_t device;
HIP_CHECK(hipDeviceGet(&device, 0));
checkVMMSupported(device);
hipMemGenericAllocationHandle_t handle;
hipMemAllocationProp allocation_prop = {};
allocation_prop.type = hipMemAllocationTypePinned;
allocation_prop.location.type = hipMemLocationTypeDevice;
allocation_prop.location.id = device;
hipMemAllocationProp allocation_prop_temp = {};
size_t granularity = 0;
size_t buffer_size = DATA_SIZE * sizeof(int);
HIP_CHECK(hipMemGetAllocationGranularity(&granularity, &allocation_prop,
hipMemAllocationGranularityMinimum));
REQUIRE(granularity > 0);
size_t mem_size = ((granularity + buffer_size - 1) / granularity) * granularity;
HIP_CHECK(hipMemCreate(&handle, mem_size, &allocation_prop, 0));
hipStream_t stream = nullptr;
HIP_CHECK(hipStreamCreate(&stream));
GENERATE_CAPTURE();
BEGIN_CAPTURE(stream);
HIP_CHECK(hipMemGetAllocationPropertiesFromHandle(&allocation_prop_temp, handle));
END_CAPTURE(stream);
HIP_CHECK(hipStreamDestroy(stream));
HIP_CHECK(hipMemRelease(handle));
CTX_DESTROY();
}
/**
* End doxygen group VirtualMemoryManagementTest.
* @}
*/